@@ -46,7 +46,7 @@ def return_app(app=app, project_name="labton_default_project"):
     ch = ConfigHandler(project_name=project_name)
     ch.load_project_config()
     app.config.update(ch.config)
-    create_db_if_not_exists(app)
+    #create_db_if_not_exists(app)
     return(app)
 
 if __name__ == "__main__":
